#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Jul 31 19:07:00 2020

@author: andremounier
"""

# In[1] Importation du module

import numpy as np


# In[2] Importation des constantes

#Constantes physiques
fichier_CSTE = open("Constantes.txt","r").read().split('\n\n')
Constantes = {}
for elem in fichier_CSTE:
	entrée = elem.split(',')
	Constantes[entrée[0]] = [float(entrée[i]) for i in range(1,len(entrée))]

#Données atmosphériques
fichier_ATM = open("Données_Atmosphère.txt","r").read().split('\n\n')
Données_Atmosphère = {}
for elem in fichier_ATM:
	entrée = elem.split(',')
	Données_Atmosphère[entrée[0]] = [float(entrée[i]) for i in range(1,len(entrée))]

#Données liées au CO2
fichier_CO2 = open("Données_CO2.txt","r").read().split('\n\n')
Données_CO2 = {}
for elem in fichier_CO2:
	entrée = elem.split(',')
	Données_CO2[entrée[0]] = [float(entrée[i]) for i in range(1,len(entrée))]

#Données liées à la vapeur d'eau
fichier_H2O = open("Données_H2O.txt","r").read().split('\n\n')
Données_H2O = {}
for elem in fichier_H2O:
	entrée = elem.split(',')
	Données_H2O[entrée[0]] = [float(entrée[i]) for i in range(1,len(entrée))]
	

# In[3] Définition des constantes

P_standard 	= Constantes['Pression standard'][0]
T_standard 	= Constantes['Température standard'][0]
Na			= Constantes["Constante d'Avogadro"][0]
R			= Constantes['Constante des gaz pafaits'][0]

Z_T			= Données_Atmosphère['Altitude de la tropopause'][0]

x0_H2O_REF 	= Données_H2O["Fraction molaire standard en vapeur d'eau"][0]	
M_H2O		= Données_H2O['Masse molaire'][0]	
h_e_REF		= Données_H2O["Hauteur caractéristique de la vapeur d'eau"][0]

Flux_solaire_REF 	= 1361/4 #W/m2
albedo_REF 			= 0.23

# In[4] Fonctions de calcul des luminances

def F_atmosphere_SW(fact_H2O, h_e = h_e_REF, a = albedo_REF, Fi = Flux_solaire_REF):
	"""
	Calcul du flux solaire
	
	 - Entrée(s) : Facteur de vapeur d'eau, Hauteur caractéristique de décroissance de la vapeur d'eau (en km), Albedo, Flux solaire incident
	 - Sortie(s) : Flux solaire absorbé  par l'atmopshère (en W/m2)
	"""
	n0_H2O = x0_H2O_REF*fact_H2O*P_standard/R/T_standard*Na*fact_H2O
	m_H2O = M_H2O*n0_H2O*h_e*1e3/Na*(1-np.exp(-Z_T/h_e))
	Tau_SW = np.sqrt(0.004*m_H2O)
	
	T_SW = np.exp(-Tau_SW)
	A_SW = 1-T_SW
	
	return Fi*A_SW*(1+T_SW*a)

def F_surface_SW(fact_H2O, h_e = h_e_REF, a = albedo_REF, Fi = Flux_solaire_REF):
	"""
	Calcul du flux solaire
	
	 - Entrée(s) : Facteur de vapeur d'eau, Hauteur caractéristique de décroissance de la vapeur d'eau (en km), Albedo, Flux solaire incident
	 - Sortie(s) : Flux solaire absorbé  par l'atmopshère (en W/m2)
	"""
	n0_H2O = x0_H2O_REF*fact_H2O*P_standard/R/T_standard*Na*fact_H2O
	m_H2O = M_H2O*n0_H2O*h_e*1e3/Na*(1-np.exp(-Z_T/h_e))
	Tau_SW = np.sqrt(0.004*m_H2O)
	
	T_SW = np.exp(-Tau_SW)
	
	return Fi*(1-a)*T_SW